"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const getComment_1 = require("./getComment");
const getEnum_1 = require("./getEnum");
const getEnumFromDescription_1 = require("./getEnumFromDescription");
const getEnumType_1 = require("./getEnumType");
const getModel_1 = require("./getModel");
const getOperationParameterDefault_1 = require("./getOperationParameterDefault");
const getOperationParameterName_1 = require("./getOperationParameterName");
const getType_1 = require("./getType");
function getOperationParameter(openApi, parameter) {
    const operationParameter = {
        in: parameter.in,
        prop: parameter.name,
        export: 'interface',
        name: getOperationParameterName_1.getOperationParameterName(parameter.name),
        type: constants_1.PrimaryType.OBJECT,
        base: constants_1.PrimaryType.OBJECT,
        template: null,
        link: null,
        description: getComment_1.getComment(parameter.description),
        default: getOperationParameterDefault_1.getOperationParameterDefault(parameter.default),
        isProperty: false,
        isReadOnly: false,
        isRequired: parameter.required === true,
        isNullable: false,
        imports: [],
        extends: [],
        enum: [],
        enums: [],
        properties: [],
    };
    if (parameter.$ref) {
        const definitionRef = getType_1.getType(parameter.$ref);
        operationParameter.export = 'reference';
        operationParameter.type = definitionRef.type;
        operationParameter.base = definitionRef.base;
        operationParameter.template = definitionRef.template;
        operationParameter.imports.push(...definitionRef.imports);
        return operationParameter;
    }
    if (parameter.enum) {
        const enumerators = getEnum_1.getEnum(parameter.enum);
        if (enumerators.length) {
            operationParameter.export = 'enum';
            operationParameter.type = getEnumType_1.getEnumType(enumerators);
            operationParameter.base = constants_1.PrimaryType.STRING;
            operationParameter.enum.push(...enumerators);
            return operationParameter;
        }
    }
    if ((parameter.type === 'int' || parameter.type === 'integer') && parameter.description) {
        const enumerators = getEnumFromDescription_1.getEnumFromDescription(parameter.description);
        if (enumerators.length) {
            operationParameter.export = 'enum';
            operationParameter.type = getEnumType_1.getEnumType(enumerators);
            operationParameter.base = constants_1.PrimaryType.NUMBER;
            operationParameter.enum.push(...enumerators);
            return operationParameter;
        }
    }
    if (parameter.type === 'array' && parameter.items) {
        const items = getType_1.getType(parameter.items.type);
        operationParameter.export = 'array';
        operationParameter.type = items.type;
        operationParameter.base = items.base;
        operationParameter.template = items.template;
        operationParameter.imports.push(...items.imports);
        return operationParameter;
    }
    if (parameter.type === 'object' && parameter.items) {
        const items = getType_1.getType(parameter.items.type);
        operationParameter.export = 'dictionary';
        operationParameter.type = items.type;
        operationParameter.base = items.base;
        operationParameter.template = items.template;
        operationParameter.imports.push(...items.imports);
        operationParameter.imports.push('Dictionary');
        return operationParameter;
    }
    if (parameter.schema) {
        if (parameter.schema.$ref) {
            const model = getType_1.getType(parameter.schema.$ref);
            operationParameter.export = 'reference';
            operationParameter.type = model.type;
            operationParameter.base = model.base;
            operationParameter.template = model.template;
            operationParameter.imports.push(...model.imports);
            return operationParameter;
        }
        else {
            const model = getModel_1.getModel(openApi, parameter.schema);
            operationParameter.export = model.export;
            operationParameter.type = model.type;
            operationParameter.base = model.base;
            operationParameter.template = model.template;
            operationParameter.link = model.link;
            operationParameter.imports.push(...model.imports);
            operationParameter.extends.push(...model.extends);
            operationParameter.enum.push(...model.enum);
            operationParameter.enums.push(...model.enums);
            operationParameter.properties.push(...model.properties);
            return operationParameter;
        }
    }
    // If the parameter has a type than it can be a basic or generic type.
    if (parameter.type) {
        const definitionType = getType_1.getType(parameter.type);
        operationParameter.export = 'generic';
        operationParameter.type = definitionType.type;
        operationParameter.base = definitionType.base;
        operationParameter.template = definitionType.template;
        operationParameter.imports.push(...definitionType.imports);
        return operationParameter;
    }
    return operationParameter;
}
exports.getOperationParameter = getOperationParameter;
