"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Handlebars = require("handlebars");
const fs = require("fs");
/**
 * Read and compile the Handlebars template.
 * @param filePath
 */
function readHandlebarsTemplate(filePath) {
    if (fs.existsSync(filePath)) {
        try {
            const template = fs
                .readFileSync(filePath, 'utf8')
                .toString()
                .trim();
            return Handlebars.compile(template, {
                strict: true,
                noEscape: true,
                preventIndent: true,
                knownHelpersOnly: true,
                knownHelpers: {
                    equals: true,
                    notEquals: true,
                },
            });
        }
        catch (e) {
            throw new Error(`Could not compile Handlebar template: "${filePath}"`);
        }
    }
    throw new Error(`Could not find Handlebar template: "${filePath}"`);
}
exports.readHandlebarsTemplate = readHandlebarsTemplate;
