"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const exportService_1 = require("./exportService");
const format_1 = require("./format");
const getFileName_1 = require("./getFileName");
/**
 * Generate Services using the Handlebar template and write to disk.
 * @param services Array of Services to write.
 * @param language The output language (Typescript or javascript).
 * @param templates The loaded handlebar templates.
 * @param outputPath
 */
function writeClientServices(services, language, templates, outputPath) {
    services.forEach(service => {
        const fileName = getFileName_1.getFileName(service.name, language);
        try {
            const templateData = exportService_1.exportService(service);
            const templateResult = templates.service(templateData);
            fs.writeFileSync(path.resolve(outputPath, fileName), format_1.format(templateResult));
        }
        catch (e) {
            throw new Error(`Could not write service: "${fileName}"`);
        }
    });
}
exports.writeClientServices = writeClientServices;
